Summary:        Real-time software synthesizer
Name:           zynaddsubfx
Version:        2.4.4
Release:        4%{?dist}
# Source is a collective work, distributed by
License:        GPLv2 and GPLv2+
Group:          Applications/Multimedia
URL:            http://zynaddsubfx.sourceforge.net
Source0:        http://download.sf.net/sourceforge/zynaddsubfx/zynaddsubfx-%{version}.tar.xz
Source1:        zynaddsubfx.desktop
# We cannot build this from source since Fedora's texlive is too old
Source2:        zynaddsubfx.pdf
Patch1:         zynaddsubfx-buildflags.patch
Patch2:         zynaddsubfx-desktop.patch

Requires:       hicolor-icon-theme
Requires:       %{name}-common = %{version}-%{release}

BuildRequires:  alsa-lib-devel
BuildRequires:  cmake
BuildRequires:  desktop-file-utils
BuildRequires:  dssi-devel
BuildRequires:  fftw3-devel
BuildRequires:  fltk-devel
BuildRequires:  fltk-fluid
BuildRequires:  ImageMagick
BuildRequires:  jack-audio-connection-kit-devel
BuildRequires:  lash-devel
BuildRequires:  mxml-devel
BuildRequires:  portaudio-devel
BuildRequires:  zlib-devel


%description
ZynAddSubFX is an open source software synthesizer capable of making a
countless number of instrument sounds. It is microtonal, and the instruments
made by it sounds like those from professional keyboards. The program has
effects like Reverb, Echo, Chorus, Phaser...

This package includes the standalone implementation of the synthesizer.

%package common
Summary:        Common files for ZynAddSubFX synthesizers
Group:          Applications/Multimedia
BuildArch:      noarch

%description common
ZynAddSubFX is an open source software synthesizer capable of making a
countless number of instrument sounds. It is microtonal, and the instruments
made by it sounds like those from professional keyboards. The program has
effects like Reverb, Echo, Chorus, Phaser...

This package includes the common files needed by the implementations of the
synthesizer.

%package dssi
Summary:        Real-time software synthesizer for DSSI
Group:          Applications/Multimedia
Requires:       %{name}-common = %{version}-%{release}
Requires:       dssi

%description dssi
ZynAddSubFX is an open source software synthesizer capable of making a
countless number of instrument sounds. It is microtonal, and the instruments
made by it sounds like those from professional keyboards. The program has
effects like Reverb, Echo, Chorus, Phaser...

This package includes the DSSI implementation of the synthesizer.

%prep
%setup -q
%patch1 -p1 -b .flags
%patch2 -p1 -b .desktop
cp -a %SOURCE2 .

# Fix encoding
for i in AUTHORS.txt ChangeLog; do
   iconv -f iso8859-1 -t utf8 $i -o tmpfile
   touch -r $i tmpfile
   mv -f tmpfile $i
done


%build
mkdir -p %{_target_platform}
pushd %{_target_platform}
   %cmake \
      -DDefaultOutput=jack \
%ifarch %{ix86} x86_64
      -DX86Build=ON \
%endif
      ..
popd

make %{?_smp_mflags} -C %{_target_platform}

# build external programs
make %{?_smp_mflags} -C ExternalPrograms/Controller
make %{?_smp_mflags} -C ExternalPrograms/Spliter


%install
make install DESTDIR=%{buildroot} -C %{_target_platform}

# Merge applications into one software center item
mkdir -p $RPM_BUILD_ROOT%{_datadir}/appdata
cat > $RPM_BUILD_ROOT%{_datadir}/appdata/zynaddsubfx-jack.appdata.xml <<EOF
<?xml version="1.0" encoding="UTF-8"?>
<!-- Copyright 2014 Richard Hughes <richard@hughsie.com> -->
<component type="desktop">
  <metadata_license>CC0-1.0</metadata_license>
  <id>zynaddsubfx-jack.desktop</id>
  <metadata>
    <value key="X-Merge-With-Parent">zynaddsubfx-alsa.desktop</value>
  </metadata>
</component>
EOF

mkdir -p %{buildroot}%{_datadir}/%{name}

cp -rp instruments/examples instruments/banks %{buildroot}%{_datadir}/%{name}

# install external programs
pushd ExternalPrograms
   install -m 0755 Controller/controller %{buildroot}%{_bindir}/zynaddsubfx-controller
   install -m 0755 Spliter/spliter %{buildroot}%{_bindir}/zynaddsubfx-spliter
popd

desktop-file-validate %{buildroot}%{_datadir}/applications/%{name}-jack.desktop
desktop-file-validate %{buildroot}%{_datadir}/applications/%{name}-alsa.desktop

# We are including these in the common package below
rm -fr %{buildroot}%{_datadir}/doc/%{name}/

%files
%{_bindir}/*
%{_datadir}/appdata/%{name}*.appdata.xml
%{_datadir}/applications/%{name}*.desktop
%{_datadir}/pixmaps/zynaddsubfx.svg

%files common
%doc AUTHORS.txt ChangeLog COPYING FAQ.txt HISTORY.txt README.txt zynaddsubfx.pdf
%{_datadir}/%{name}/

%files dssi
%{_libdir}/dssi/*.so

%changelog
* Thu Mar 26 2015 Richard Hughes <rhughes@redhat.com> - 2.4.4-4
- Add an AppData file for the software center

* Thu Feb 19 2015 Rex Dieter <rdieter@fedoraproject.org> 2.4.4-3
- rebuild (fltk)

* Mon Aug 18 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.4.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sun Jun 29 2014 Brendan Jones <brendan.jones.it@gmail.com> 2.4.4-1
- Update to 2.4.4

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.4.3-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.4.3-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Sun Feb 10 2013 Parag Nemade <paragn AT fedoraproject DOT org> - 2.4.3-3
- Remove vendor tag from desktop file as per https://fedorahosted.org/fesco/ticket/1077

* Sun Oct 28 2012 Brendan Jones <brendan.jones.it@gmail.com> 2.4.3-2
- Mov ebanks/examples

* Thu Oct 25 2012 Brendan Jones <brendan.jones.it@gmail.com> 2.4.3-1
- New upstream release

* Sun Jul 22 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.4.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Thu Mar 08 2012 Orcan Ogetbil <oget [DOT] fedora [AT] gmail [DOT] com> - 2.4.2-1
- 2.4.2

* Tue Feb 28 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.4.1-5
- Rebuilt for c++ ABI breakage

* Sat Jan 14 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.4.1-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Sun Jun 26 2011 Orcan Ogetbil <oget [DOT] fedora [AT] gmail [DOT] com> - 2.4.1-3
- Fix FTBFS RHBZ#715835

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.4.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Thu Jul 22 2010 Orcan Ogetbil <oget [DOT] fedora [AT] gmail [DOT] com> - 2.4.1-1
- Version update
- Build the DSSI plugin since it is fixed now
- Put the common files between standalone ad DSSI synths in a common package
- Drop patches that are not necessary anymore
- Fix .desktop file

* Wed Feb 10 2010 Orcan Ogetbil <oget [DOT] fedora [AT] gmail [DOT] com> - 2.4.0-3
- Fix DSO-linking failure

* Tue Sep 08 2009 Orcan Ogetbil <oget[DOT]fedora[AT]gmail[DOT]com> - 2.4.0-2
- Bugfix: presets and parameters don't load on ix86 (RHBZ #518755)

* Thu Aug 06 2009 Orcan Ogetbil <oget[DOT]fedora[AT]gmail[DOT]com> - 2.4.0-1
- Update to 2.4.0
- Update scriptlets according to new guidelines
- Update the .desktop file
- Use Fedora specific flags during compilation
- License is GPLv2+ (just run the program on the command line :))

* Mon Jul 27 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2.1-21
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2.1-20
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Mon Aug 11 2008 Jason L Tibbitts III <tibbs@math.uh.edu> - 2.2.1-19
- Fix license tag.

* Mon Feb 18 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 2.2.1-18
- Autorebuild for GCC 4.3

* Wed Oct 10 2007 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.2.1-17
- added tweaked unzombify patch by Lars Luthman (patch3), see:
  http://sourceforge.net/tracker/index.php?func=detail&aid=1498438&group_id=62934&atid=502314

* Tue Oct 09 2007 Anthony Green <green@redhat.com> 2.2.1-16
- Rebuilt for new lash again.

* Mon Oct 08 2007 Anthony Green <green@redhat.com> 2.2.1-15
- Rebuilt for new lash.

* Wed Mar 14 2007 Anthony Green <green@redhat.com> 2.2.1-14
- Rebuild with new ImageMagick for working desktop icons.

* Thu Oct 05 2006 Christian Iseli <Christian.Iseli@licr.org> 2.2.1-13
 - rebuilt for unwind info generation, broken in gcc-4.1.1-21

* Tue Sep 19 2006 Anthony Green <green@redhat.com>  2.2.1-12
- Fix release tag.

* Mon Sep 18 2006 Anthony Green <green@redhat.com>  2.2.1-11.1
- Rebuild.

* Wed Aug 30 2006 Anthony Green <green@redhat.com>  2.2.1-11
- Fix ppc problem (in a different way).

* Wed Aug 30 2006 Anthony Green <green@redhat.com>  2.2.1-10
- Fix ppc problem.  Add perl dependency.

* Wed Aug 30 2006 Anthony Green <green@redhat.com>  2.2.1-9
- Only build for x86 and x86-64 for now.  (ppc build problem)

* Wed Aug 30 2006 Anthony Green <green@redhat.com>  2.2.1-8
- Depend on hicolor-icon-theme.

* Sat Aug 26 2006 Anthony Green <green@redhat.com>  2.2.1-7
- Add dist tag to release version.
- Tidy up description.
- Use standard scriptlets in %%post/%%postun.

* Thu Jul 20 2006 Anthony Green <green@redhat.com>  2.2.1-6
- Fix compile options and remove rpath usage (bug in fltk-config).

* Sat Jul 15 2006 Anthony Green <green@redhat.com>  2.2.1-5
- First Fedora Extras build.
- Fix Source0 permissions.
- Add desktop-file-utils requirements.
- Tweak macro usage and .desktop file.
- Convert and install icons.  Add post(un) install scripts.
- Add ImageMagick BuildRequires.

* Mon May  8 2006 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.2.1-4
- added lash patch (http://www.student.nada.kth.se/~d00-llu/programming.php)

* Sat May  6 2006 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.2.1-3
- add Planet CCRMA categories to desktop file

* Fri Mar 31 2006 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 
- build on fc5

* Fri Sep 23 2005 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.2.1-2
- rebuilt with new version of mxml (2.2.2)
- added specific requires for mxml version

* Tue May  3 2005 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.2.1-1
- updated to 2.2.1

* Fri Apr  8 2005 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.2.0-1
- updated to 2.2.0

* Mon Feb  7 2005 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.1.1-2
- fixed microtuning bug (patch from Paul Nasca)

* Sun Oct  3 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.1.1-1
- updated to 2.1.1

* Fri Oct  1 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.1.0-1
- updated to 2.1.0

* Fri Aug 27 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.0.0-1
- updated to 2.0.0 final
- readded examples directory to the file list
- installed banks and presets
- compiled and installed "controller" and "spliter"

* Wed Aug  4 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.0.0-0.pre2.1
- updated to latest prerelease
- added mxml build dependency, updated requirements to fftw3
- no documentation or examples for now

* Sat Nov  8 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 1.4.3-1
- spec file tweaks

* Mon Sep  1 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 1.4.3-1
- updated to 1.4.3, added release tag

* Fri Jul 25 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 1.4.2-1
- updated to 1.4.2

* Thu May  8 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 1.4.1-1
- updated to 1.4.1 (docs are still 1.4.0)

* Tue May  6 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 1.4.0-1
- updated to 1.4.0

* Tue Apr  8 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 1.2.1-2
- rebuilt for newer version of fftw

* Tue Apr  8 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 1.2.1-1
- udpated to 1.2.1

* Wed Apr  2 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 1.2.0-2
- rebuild for jack 0.66.3, added explicit requires for it

* Fri Mar 21 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 1.2.0-1
- updated to 1.2.0

* Thu Mar  6 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 1.0.9-2
- rebuilt due to changed fltk (from 1.1.0rc3 to 1.1.3)
- commented out deprecated jack_set_buffer_size_callback() call

* Mon Feb 24 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 1.0.9-1
- updated to 1.0.9

* Fri Feb 14 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 1.0.8-1
- updated to 1.0.8

* Fri Feb  6 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 1.0.7-1
- updated to 1.0.7

* Sun Jan 26 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 1.0.5-1
- Initial build.
